@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # feed2twitter
 # Copyright (C) 2008 EBC - Empresa Brasil de Comunicação
 #
@@ -27,9 +28,12 @@ class Options(object):
         self.parser.add_option("-p", "--print_sample_config",
                   action="store_true", dest="sample_config", default=False,
                   help="print a sample config file and exit")
+        self.parser.add_option("-v", "--version",
+                  action="store_true", dest="show_version", default=False,
+                  help="Show the feed2mb version")
     def parse(self):
         (options, args) = self.parser.parse_args()
-        if not options.config_filename and not options.sample_config:
+        if not options.config_filename and not options.sample_config and not options.show_version:
             self.parser.print_help()
             sys.exit()
         return options
